#! /usr/bin/env python
'''
Module Name:    SampoVideoFwFlash.py

Description:    Class for Flashing Sampo Video FW Update

Copyright:      Toshiba Confidential

                OCO Source Materials

                Copyright (C) 2012,2013 Toshiba Global Commerce Solutions, Inc.

                The source code for this program is not published
                or otherwise divested of its trade secrets,
                irrespective of what has been deposited with the
                U. S. Copyright Office.

Initial Author: Francisco Liwa

Function:

Notes:

Dependencies:    None

Restrictions:    None

Last Modified: 30 September 2013
'''

from monitorupgrade import TLog as TLOG
from monitorupgrade import Utils as utils

EXIT_SUCCESS = 0
SAMPO_UTIL = '/opt/toshiba/mus/op_utils/sampo/4820MonUtil'
MUS_LOG_FILE_DIR = '/var/log/toshiba/mus/latest/'


#==========================================================================================================
#VideoFwFlashTask_4820_21x51x - Class for Flashing 4820_21x51x Video FW Update
##==========================================================================================================    
class VideoFwFlashTask_4820_21x51x:
    fw_path=''
    fw_name=''
    controller=''
    def __init__(self,path,controller):
        '''
        Constructor
        '''
        TLOG.logger.info('SampoVideoFlashTask_4820_21x51x Constructed')
        self.fw_path = path
        self.controller = controller
         
    def run(self):
        TLOG.logger.info('SampoVideoFlashTask_4820_21x51x::run() -----------------START---------------')
        
        #sampoCommand = SAMPO_UTIL +  '  -SELECT=' + self.controller + ' -FW_LOCATION=' + str(self.fw_path)
        sampoCommand = SAMPO_UTIL +  '  -SELECT=ALL  -FW_LOCATION=' + str(self.fw_path)
         
        if utils.doesFileExist(SAMPO_UTIL) != True:         
            print '[SampoVideoFlashTask_4820_21x51x] - No Sampo Utility found!'
            TLOG.logger.error('SampoVideoFlashTask_4820_21x51x::run()-No Sampo Utility found!')
            raise IOError('No Sampo Utility found!')
        else:
            print "[SampoVideoFlashTask_4820_21x51x] - This will take some time,Please wait ..."
            ret = utils.runSubprocess(sampoCommand,'SampoVideoFlashTask_4820_21x51x')
        
        if ret != EXIT_SUCCESS:
            return ret #return immediately
        else:
            print '[SampoVideoFlashTask_4820_21x51x] - Task Completed! - Please check log file at '  + MUS_LOG_FILE_DIR         
            TLOG.logger.info('SampoVideoFlashTask_4820_21x51x::run() -----------------END-----------------\n')
            return ret
    

##==========================================================================================================
#VideoFwFlashTask_4820_2Lx5Lx - Class for Flashing 4820_2Lx5Lx Video FW Update
##========================================================================================================== 
class VideoFwFlashTask_4820_2Lx5Lx:
    fw_path=''
    controller=''
    
    def __init__(self,path,controller):
        '''
        Constructor
        ''' 
        TLOG.logger.info('SampoVideoFlashTask_4820_2Lx5Lx Constructed')
        self.fw_path = path
        self.controller = controller
        
    def run(self):
        TLOG.logger.info('SampoVideoFlashTask_4820_2Lx5Lx::run() -----------------START---------------')
        
        #sampoCommand = SAMPO_UTIL +  '  -SELECT=' + self.controller + ' -FW_LOCATION=' + str(self.fw_path)
        sampoCommand = SAMPO_UTIL +  '  -SELECT=ALL -FW_LOCATION=' + str(self.fw_path) 
            
        if utils.doesFileExist(SAMPO_UTIL) != True:
            
            print '[SampoVideoFlashTask_4820_2Lx5Lx] - No Sampo Utility found!'
            TLOG.logger.error('SampoVideoFlashTask_4820_2Lx5Lx::run()-No Sampo Utility found!')
            raise IOError('No Sampo Utility found!')
        else:
            print "[SampoVideoFlashTask_4820_2Lx5Lx] - This will take some time,Please wait ..."
            ret = utils.runSubprocess(sampoCommand,'SampoVideoFlashTask_4820_2Lx5Lx') 
        
        if ret != EXIT_SUCCESS:
            return ret #return immediately
        else:
            print '[SampoVideoFlashTask_4820_2Lx5Lx] - Task Completed! - Please check log file at '  + MUS_LOG_FILE_DIR         
            TLOG.logger.info('SampoVideoFlashTask_4820_2Lx5Lx::run() -----------------END-----------------\n')
            return ret

##==========================================================================================================
#VideoFwRecoveryFlashTask - Class for the Sampo Recovery Task for Video Flash
##==========================================================================================================        
class VideoFwRecoveryFlashTask:
    def __init__(self):
        '''
        Constructor
        '''
        #print 'SampoVideoFlashRecoveryTask Constructed'
        TLOG.logger.info('SampoVideoFlashRecoveryTask Constructed')
          
    def run(self,cmd):
        TLOG.logger.info('SampoVideoFlashRecoveryTask::run()-----------------START---------------')
                    
        ret = utils.runShell(str(cmd))
        print 'SampoVideoFlashRecoveryTask Done.' + '{' + str(ret) + '}'
        
        TLOG.logger.info('SampoVideoFlashRecoveryTask::run() - Cleaning after.local file \n')
        utils.runShell('cp /opt/toshiba/mus/op_utils/sampo/rc.local /etc/init.d/after.local') 
        
        TLOG.logger.info('SampoVideoFlashRecoveryTask::run()-----------------END-----------------\n')
        print 'System is rebooting now...'
        utils.runShell('reboot')
        
        #return EXIT_SUCCESS